@@ -1,21 +1,23 @@
+source("wrap_examples.R")
+
 context('RcppProgressExample sequential\n')
 
 .test_sequential <- function() {
-  expect_error(RcppProgress:::test_sequential(nb = 500), NA)
+  expect_error(test_sequential(nb = 500), NA)
 }
 test_that("test_sequential", .test_sequential())
 
 
 context('RcppProgressExample multithreaded\n')
 .test_multithreaded <- function() {
-  RcppProgress:::test_multithreaded(nb = 1000, threads = 4)
+  expect_error(test_multithreaded(nb = 1000, threads = 4), NA)
 }
 test_that("test_multithreaded", .test_multithreaded())
 
 
 context('RcppProgressArmadillo multithreaded\n')
 .amardillo_multithreaded <- function() {
-  RcppProgress:::amardillo_multithreaded(nb = 1000, threads = 4)
+  expect_error(amardillo_multithreaded(nb = 1000, threads = 4), NA)
 }
 test_that("amardillo_multithreaded", .amardillo_multithreaded())
 
@@ -23,6 +25,6 @@ test_that("amardillo_multithreaded", .amardillo_multithreaded())
 
 context('RcppProgressETA:custom progress bar\n')
 .eta_progress_bar <- function() {
-  RcppProgress:::eta_progress_bar(nb = 1000)
+  expect_error(eta_progress_bar(nb = 1000), NA)
 }
-test_that("eta_progress_bar", .eta_progress_bar())
\ No newline at end of file
+test_that("eta_progress_bar", .eta_progress_bar())
